pub struct DiscoveryClient { /* private fields */ }Expand description
Stateless discovery helper that wraps the protocol request/response models.
Implementations
Sourceimpl DiscoveryClient
impl DiscoveryClient
Sourcepub fn new(options: DiscoveryClientOptions) -> Result<Self, DiscoveryError>
pub fn new(options: DiscoveryClientOptions) -> Result<Self, DiscoveryError>
Creates a client that will send discovery packets to remote_addr.
Sourcepub fn discover(
&self,
requested: &[String],
) -> Result<DiscoveryOutcome, DiscoveryError>
pub fn discover( &self, requested: &[String], ) -> Result<DiscoveryOutcome, DiscoveryError>
Sends a discovery payload with the requested capability names and waits for a reply.